@@ -57,7 +57,7 @@ SLUGIFY_HYPHENATE_RE = re.compile(r"[-\s]+")
 _SANITIZE_KEYS = ['adminPass', 'admin_pass', 'password', 'admin_password',
                   'auth_token', 'new_pass', 'auth_password', 'secret_uuid',
                   'secret', 'sys_pswd', 'token', 'configdrive',
-                  'CHAPPASSWORD', 'encrypted_key']
+                  'CHAPPASSWORD', 'encrypted_key', 'private_key']
 
 # NOTE(ldbragst): Let's build a list of regex objects using the list of
 # _SANITIZE_KEYS we already have. This way, we only have to add the new key
@@ -323,16 +323,16 @@ def mask_dict_password(dictionary, secret="***"):  # nosec
     A dictionary (which may contain nested dictionaries) contains
     information (such as passwords) which should not be revealed, and
     this function helps detect and replace those with the 'secret'
-    provided (or '***' if none is provided).
+    provided (or `***` if none is provided).
 
     Substitution is performed in one of three situations:
 
     If the key is something that is considered to be indicative of a
     secret, then the corresponding value is replaced with the secret
-    provided (or '***' if none is provided).
+    provided (or `***` if none is provided).
 
     If a value in the dictionary is a string, then it is masked
-    using the mask_password() function.
+    using the ``mask_password()`` function.
 
     Finally, if a value is a dictionary, this function will
     recursively mask that dictionary as well.
